
.. image:: https://github.com/Vital-Fernandez/lime/blob/0afedb150b0169deec6c7f159def99750a3a30da/docs/source/_static/logo_transparent.png?raw=true
    :width: 50%
    :align: center
    :alt: Line Measurer (LiMe) library.

|Repo status| |CI badge| |Documentation Status| |Code cov| |PyPI version| |PyPI downloads| |Code Size| |PyPI license|

This library provides a set of tools to fit lines in astronomical spectra. Its design aims for a user-friendly workflow
for both single lines and large data sets. The functions can be used for masking data, detecting lines, fitting profiles
and storing the results. The output measurements support the chemical and kinematic analysis of the observed transitions.

Please check the `online documentation <https://lime-stable.readthedocs.io/>`_.

Installation
============

The library can be installed directly from its PyPi_ project page running the command:

``pip install lime-stable``

Development
===========

LiMe is currently on its initial release. Any comment/issue/request can be added as an issue on the github_ page.

.. _PyPi: https://pypi.org/project/lime-stable/
.. _github: https://github.com/Vital-Fernandez/lime

.. |Repo status| image:: http://www.repostatus.org/badges/latest/active.svg
    :target: http://www.repostatus.org/#active
    :alt: Project Status: Active – The project has reached a stable, usable state and is being actively developed.

.. |Version lime-stable| image:: https://badge.fury.io/py/lime-stable.svg
   :target: https://pypi.org/project/lime-stable/

.. |PyPI license| image:: https://img.shields.io/pypi/l/lime-stable
   :alt: PyPI - License

.. |PyPI downloads| image:: https://static.pepy.tech/badge/lime-stable
   :target: https://static.pepy.tech/badge/lime-stable
   :alt: PyPI - License

.. |Documentation Status| image:: https://readthedocs.org/projects/lime-stable/badge/?version=latest
   :target: http://lime-stable.readthedocs.io/?badge=latest

.. |Code Size| image:: https://img.shields.io/github/languages/code-size/Vital-Fernandez/lime
   :target: http://lime-stable.readthedocs.io/?badge=latest
   :alt: GitHub code size in bytes

.. |Code cov| image:: https://codecov.io/gh/Vital-Fernandez/lime/branch/master/graph/badge.svg?token=4ZW8EATXN7
   :target: https://codecov.io/gh/Vital-Fernandez/lime

.. |CI badge| image:: https://img.shields.io/circleci/build/gh/Vital-Fernandez/lime/master?logo=CircleCi
   :target: https://circleci.com/gh/Vital-Fernandez/lime/?branch=master

.. |PyPI version| image:: https://img.shields.io/pypi/v/lime-stable.svg?logo=Python&logoColor=white?labelColor=blue
   :target: https://pypi.org/project/lime-stable

